/**
 * ixm0jssdk
 * @since 2019/06/11
 */
(function(factory) {
	'use strict'

	if(typeof define === 'function' && define.amd) {
		define(factory)
	} else if(typeof module != 'undefined' && typeof module.exports != 'undefined') {
		module.exports = factory()
	} else if(typeof Package !== 'undefined') {
		ixm = factory() // export for Meteor.js
	} else {
		/* jshint sub:true */
		window['ixm'] = factory()
	}
})(function() {

	var deviceType
	var MAX_SIZE = '2097152'

	var privateMethods = {

		/**
		 * 判断设备类型
		 */
		getDeviceType: function() {
			var deviceType = 'H5'
			if(typeof(innoPlus) !== 'undefined') {
				deviceType = 'IOS'
			} else if(typeof(android) !== 'undefined') {
				deviceType = 'ANDROID'
			}
			return deviceType
		},

		addParams: function(path, paramsObj) {
			var params = ''

			if(!paramsObj) {
				return
			}

			for(index in paramsObj) {
				if(!paramsObj[index]) {
					continue
				}
				if(!params) {
					params += index + '=' + paramsObj[index]
				} else {
					params += '&' + index + '=' + paramsObj[index]
				}
			}

			if(path.indexOf('?') > -1) {
				path = path + '&' + params
			} else {
				path = path + params
			}

			return path
		},

		/**
		 * 初始化分享
		 */
		shareInit: function(shareInfo) {
			deviceType = privateMethods.getDeviceType()
			if(deviceType == 'IOS') {
				innoPlus.native.share(JSON.stringify(shareInfo))
			} else if(deviceType == 'ANDROID') {
				android.share(JSON.stringify(shareInfo))
			}
		},

		/**
		 * 获取版本号
		 */
		getVerCode: function() {
			if(deviceType == 'ANDROID') {
				return android.getVerCode()
			} else if(deviceType == 'IOS') {
				return innoPlus.baseParam.appversion
			}
		},

		/**
		 * 获取版本名
		 */
		getVerName: function() {
			if(deviceType == 'ANDROID') {
				return android.getVerName()
			} else if(deviceType == 'IOS') {
				return innoPlus.baseParam.appversion
			}
		},

		/**
		 * 按钮分享
		 */
		shareHandle: function(shareInfo) {
			if(deviceType == 'IOS') {
				innoPlus.native.showSharePopView(JSON.stringify(shareInfo))
			} else if(deviceType == 'ANDROID') {
				android.shareDialog(JSON.stringify(shareInfo))
			}
		},

		/**
		 * 从手机相册中选图接口
		 */
		chooseImage: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.chooseImage('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.chooseImage(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 拍摄图片
		 */
		takeImage: function(callback) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.takeImage('callbackObj')
			} else if(deviceType == 'IOS') {
				innoPlus.native.takeImage(callback)
			}
		},

		/**
		 * 预览图片
		 */
		previewImage: function(obj) {
			if(deviceType == 'ANDROID') {
				android.previewImage(JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.previewImage(JSON.stringify(obj))
			}
		},

		/**
		 * 下载图片
		 */
		downloadImage: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.downloadImage('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.downloadImage(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 下载base64图片
		 */
		downloadBase64Image: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.downloadBase64Image('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.downloadImage(callback, JSON.stringify(obj))
			}
		},
		/**
		 * 下载文件
		 * obj : {
		 *		fileName 文件名称  必填
		 *		fileFormat 文件后缀（下载到本地的后缀，如pdf） 必填
		 *		base64data 文件对应的base64（跟fileUrl两个之中必须传一个）
		 *		fileUrl 文件对应的网络路径（跟base64data两个之中必须传一个）
		 *		openFlag 下载后是否要打开文件，1是打开，不传或者传0是不打开
		 * }
		 *
		 * 注意：ios 无openFlag参数，可传可不传
		 */
		downloadFile: function(obj) {
			if(deviceType == 'ANDROID') {
				android.downloadFile(JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.downloadFile(JSON.stringify(obj))
			}
		},
		/**
		 * 获取本地图片
		 */
		getLocalImgData: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.getLocalImgData('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.getLocalImgData(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 开始录音
		 */
		startRecord: function(callback) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.startRecord('callbackObj')
			} else if(deviceType == 'IOS') {
				innoPlus.native.startRecord(callback)
			}
		},

		/**
		 * 停止录音
		 */
		stopRecord: function(callback) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.stopRecord('callbackObj')
			} else if(deviceType == 'IOS') {
				innoPlus.native.stopRecord(callback)
			}
		},

		/**
		 * 开始播放
		 */
		playVoice: function(url) {
			if(deviceType == 'ANDROID') {
				android.playVoice(url)
			} else if(deviceType == 'IOS') {
				innoPlus.native.playVoice(url)
			}
		},

		/**
		 * 暂停播放
		 */
		pauseVoice: function() {
			if(deviceType == 'ANDROID') {
				android.pauseRecord()
			} else if(deviceType == 'IOS') {
				innoPlus.native.pauseRecord()
			}
		},

		/**
		 * 停止播放
		 */
		stopVoice: function() {
			if(deviceType == 'ANDROID') {
				android.stopVoice()
			} else if(deviceType == 'IOS') {
				innoPlus.native.stopVoice()
			}
		},

		/**
		 * 人脸认证
		 */
		faceAuthWithRegister: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.faceAuthWithRegisterNew('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.faceAuthWithRegisterNew(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 验证人脸认证
		 */
		faceAuthWithAEO: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.faceAuthWithAEONew('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.faceAuthWithAEONew(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 市民卡人脸认证
		 */
		openSMKFaceAuth: function(callback) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openSMKFaceAuth('callbackObj')
			} else if(deviceType == 'IOS') {
				innoPlus.native.openSMKFaceAuth(callback)
			}
		},

		/**
		 * 市民卡人脸认证静默
		 */
		openSMKBySilentFaceAuth: function(callback) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openSMKBySilentFaceAuth('callbackObj')
			} else if(deviceType == 'IOS') {
				innoPlus.native.openSMKBySilentFaceAuth(callback)
			}
		},
		
		/**
		 * 绑定银行卡
		 */
		openXMSMKBindBankCard: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openXMSMKBindBankCard('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.openXMSMKBindBankCard(callback, JSON.stringify(obj))
			}
		},
		
		/**
		 * 打开银行卡信息
		 */
		openXMSMKGoCardList: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openXMSMKGoCardList('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.openXMSMKGoCardList(callback, JSON.stringify(obj))
			}
		},
		
		/**
		 * 一手签（预览）
		 */
		openEhandsign: function(callback, params) {
			if(deviceType == 'IOS') {
				innoPlus.native.openEhandsign(callback, JSON.stringify(params))
			} else if(deviceType == 'ANDROID') {
				window.callbackObj = function(data) {
					typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
				}
				android.openEhandsign('callbackObj', JSON.stringify(params))
			}
		},
		
		/**
		 * 银行卡认证
		 */
		bankCardValidate: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.bankCardValidate('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.bankCardValidate(callback, JSON.stringify(obj))
			}
		},

		/**
		 * ixm支付
		 */
		openPay: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openXMSMKPay('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.openXMSMKPay(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 选择卡包
		 */
		openSelectCard: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.openXMSMKSelectCard('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.openXMSMKSelectCard(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 相机衡平能力
		 */
		takeIDCardImage: function(callback, obj) {
			window.callbackObj = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'ANDROID') {
				android.takeIDCardImage('callbackObj', JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.takeIDCardImage(callback, JSON.stringify(obj))
			}
		},

		/**
		 * 获取APP名称（主要用来判断市民云）
		 */
		getAppName: function() {
			var appName = ''
			if(deviceType == 'ANDROID') {
				appName = android.getAppName()
			} else if(deviceType == 'IOS') {
				appName = innoPlus.device.appname
			}
			return appName.toLocaleLowerCase()
		},

		/**
		 * 打开app页面
		 */
		openAppPage: function(pageId, params, frameOpen) {
			var path = ''
			var options = {
				pageId: pageId
			}
			options = $.extend(true, options, params)

			if(deviceType == 'ANDROID') {
				path = privateMethods.addParams('native://openwindow?', options)
				android.openWindow(path)
			} else if(deviceType == 'IOS') {
				path = privateMethods.addParams('', options)
				innoPlus.native.openWindow(path)
			}
		},
		
		/**
		 * 打开服务
		 */
		openServicePage: function(obj) {
			if(deviceType == 'ANDROID') {
				android.openServicePage(JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.openServicePage(JSON.stringify(obj))
			}
		},
		
		/**
		 * 打开登陆页
		 */
		openLogin: function(url) {

			if(deviceType == 'ANDROID') {
				android.openLogin(url || '')
			} else if(deviceType == 'IOS') {
				innoPlus.native.openLoginPage(true)
			}

		},

		/**
		 * 获取app用户标识
		 */
		getUserId: function() {
			if(deviceType == 'IOS') {

				return innoPlus.session.userId
			} else if(deviceType == 'ANDROID') {
				return android.getUserId()
			}
		},

		/**
		 * 回退
		 */
		back: function() {

			if(deviceType == 'IOS') {
				innoPlus.native.back()
			} else if(deviceType == 'ANDROID') {
				android.back()
			} else {

			}
		},

		/**
		 * 关闭webview
		 */
		close: function() {

			if(deviceType == 'IOS') {
				innoPlus.native.close()
			} else if(deviceType == 'ANDROID') {
				android.close()
			}
		},

		/**
		 * 隐藏头部
		 */
		hideHeader: function() {

			if(deviceType == 'IOS') {
				innoPlus.native.hideNavbar()
			} else if(deviceType == 'ANDROID') {
				android.hideHeader()
			}
		},

		/**
		 * 获取token
		 */
		getToken: function() {

			if(deviceType == 'IOS') {
				return innoPlus.session.token
			} else if(deviceType == 'ANDROID') {
				return android.getToken()
			}
		},

		/**
		 * 获取osType
		 */
		getOsType: function() {
			var osType = ''
			if(deviceType == 'ANDROID') {
				osType = 'Android'
			} else if(deviceType == 'IOS') {
				osType = 'iOS'
			}
			return osType
		},

		/**
		 * 获取token
		 */
		getDeviceId: function() {

			if(deviceType == 'IOS') {
				return innoPlus.device.uuid
			} else if(deviceType == 'ANDROID') {
				return android.getDeviceId()
			}
		},

		/**
		 * 隐藏分享
		 */
		hideShare: function() {
			if(deviceType == 'IOS') {
				innoPlus.native.hideShareBtn()
			} else if(deviceType == 'ANDROID') {
				android.hideShare()
			}
		},

		/**
		 * 设置头部标题
		 */
		setTitle: function(title) {
			if(deviceType == 'IOS') {
				innoPlus.native.setTitle(title)
			} else if(deviceType == 'ANDROID') {
				android.setTitle(title)
			}
		},

		/**
		 * 获取浏览器所属系统
		 */
		getBrowerType: function() {
			if(deviceType == 'H5') {
				if(mui.os.ios) {
					return 'B_IOS'
				} else if(mui.os.android) {
					return 'B_ANDROID'
				}

				return null
			}
		},

		/**
		 * 获取APP地址
		 */
		getAddress: function(callback) {

			window.getAddr = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}
			if(deviceType == 'IOS') {
				innoPlus.native.selectAddress(callback)
			} else if(deviceType == 'ANDROID') {
				android.selectAddress('getAddr')
			}
		},

		/**
		 * 选择材料
		 */
		selectMaterial: function(callback) {

			window.selectMaterial = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}

			if(deviceType == 'IOS') {
				innoPlus.native.selectMaterial(callback, MAX_SIZE)
			} else if(deviceType == 'ANDROID') {
				android.selectMaterial('selectMaterial', MAX_SIZE)
			}
		},

		/**
		 * 生成材料
		 */
		generateMaterial: function(callback) {

			window.generateMaterial = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}

			if(deviceType == 'IOS') {
				innoPlus.native.generateMaterial(callback, MAX_SIZE)
			} else if(deviceType == 'ANDROID') {
				android.generateMaterial('generateMaterial', MAX_SIZE)
			}
		},

		/**
		 * 生成材料（自定义材料名）
		 */
		createMaterial: function(callback) {
			window.createMaterial = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}

			if(deviceType == 'IOS') {
				innoPlus.native.createMaterial(callback, MAX_SIZE)
			} else if(deviceType == 'ANDROID') {
				android.createMaterial('createMaterial', MAX_SIZE)
			}
		},

		/**
		 * 复制
		 */
		copyToClipboard: function(str) {

			if(deviceType == 'IOS') {
				innoPlus.native.paste(str)
				mui.toast('复制成功')
			} else if(deviceType == 'ANDROID') {
				android.copyToClipboard(str)
				mui.toast('复制成功')
			}
		},

		/**
		 * 拨打电话
		 */
		openDial: function(phoneNumber) {
			if(deviceType == 'IOS') {

			} else if(deviceType == 'ANDROID') {
				android.openDial(phoneNumber)
			}
		},

		/**
		 * 预览pdf文件
		 */
		previewPDF: function(fileName, fileUrl) {
			if(deviceType == 'IOS') {
				var params = {
					fileName: fileName,
					fileUrl: fileUrl
				}
				innoPlus.native.previewPDF(JSON.stringify(params))
			} else if(deviceType == 'ANDROID') {
				android.openPDF(fileName, fileUrl)
			}
		},

		/**
		 * 选择代理企业列表
		 */
		selectAgentEnterprise: function(callback) {

			window.selectAgentEnterprise = function(data) {
				typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
			}

			if(deviceType == 'IOS') {

				innoPlus.native.selectAgentEnterprise(function(data) {
					callback && callback(data)
				})
			} else if(deviceType == 'ANDROID') {
				android.selectAgentEnterprise('selectAgentEnterprise')
			}

		},

		/**
		 * 调用APP人脸认证页面
		 */
		appFaceAuth: function(callback) {

			if(deviceType == 'IOS') {
				innoPlus.native.faceAuth(function(data) {
					callback && callback(data)
				})
			} else if(deviceType == 'ANDROID') {
				window.appFaceAuth = function(data) {
					typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
				}
				android.faceAuth('appFaceAuth')
			}
		},

		/**
		 * 调用APP完善企业信息
		 */
		appEnterpriseInfo: function(callback) {

			if(deviceType == 'IOS') {
				innoPlus.native.enterpriseInfo(function(data) {
					callback && callback(data)
				})
			} else if(deviceType == 'ANDROID') {
				window.appEnterpriseInfo = function(data) {
					typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
				}
				android.enterpriseInfo('appEnterpriseInfo')
			}
		},

		/**
		 * 获取APP基础参数
		 */
		getBaseParams: function() {

			if(deviceType == 'IOS') {

				return innoPlus.baseParam
			} else if(deviceType == 'ANDROID') {

				try {
					var androidObj = android.getBaseParams()
					if(typeof(androidObj) == 'string') {
						androidObj = JSON.parse(androidObj)
					}
					return androidObj
				} catch(e) {
					return undefined
				}
			}
		},
		
		/**
		 * 导航
		 * @param {Object} obj
		 */
		navigation : function(obj){
			if(deviceType == "IOS"){
				innoPlus.map.nav(JSON.stringify(obj))
			}else if(deviceType == "ANDROID"){
				android.navigation(JSON.stringify(obj))
			}
		},
		
		/**
		 * 打开客服
		 */
		openCustomerService: function() {
			if(deviceType == 'ANDROID') {
				android.openCustomerService()
			} else if(deviceType == 'IOS') {
				innoPlus.native.openCustomerService()
			}
		},

		takeCertificatePhoto: function(obj) {
			if(deviceType == 'ANDROID') {
				window.takeCertificatePhoto = function(data) {
					typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
				}
				android.takeCertificatePhoto(takeCertificatePhoto, obj)
			} else if(deviceType == 'IOS') {
				innoPlus.native.takeCertificatePhoto(function(data) {
					callback && callback(data)
				}, obj)
			}
		},
		// 港澳台及外籍认证自动审核
		crjCtidldentityVerification: function(callback,obj) {
			if(deviceType == 'ANDROID') {
				window.crjCtidldentityVerification = function(data) {
					typeof data == 'string' ? callback(JSON.parse(data)) : callback(data)
				}
				android.crjCtidldentityVerification(crjCtidldentityVerification, JSON.stringify(obj))
			} else if(deviceType == 'IOS') {
				innoPlus.native.crjCtidldentityVerification(function(data) {
					callback && callback(data)
				}, JSON.stringify(obj))
			}
		},
	}

	window.onload = function() {
		deviceType = privateMethods.getDeviceType()
	}

	return {

		/**
		 * 获取版本号
		 */
		getVerCode: privateMethods.getVerCode,

		/**
		 * 获取版本名
		 */
		getVerName: privateMethods.getVerName,

		/**
		 * 下载base64图片
		 */
		downloadBase64Image: privateMethods.downloadBase64Image,

		/**
		 * 打开app页面
		 */
		openAppPage: privateMethods.openAppPage,
		
		/**
		 * 打开app服务
		 */
		openServicePage: privateMethods.openServicePage,
		
		/**
		 * 获取设备类型
		 */
		getDeviceType: privateMethods.getDeviceType,

		/**
		 * 回退
		 */
		back: privateMethods.back,

		/**
		 * 关闭
		 */
		close: privateMethods.close,

		/**
		 * 隐藏头部
		 */
		hideHeader: privateMethods.hideHeader,

		/**
		 * 获取app用户表示
		 */
		getUserId: privateMethods.getUserId,

		/**
		 * 获取getToken
		 */
		getToken: privateMethods.getToken,

		/**
		 * 获取osType
		 */
		getOsType: privateMethods.getOsType,

		/**
		 * 获取app设备标识
		 */
		getDeviceId: privateMethods.getDeviceId,

		/**
		 * 设置app头部
		 */
		setTitle: privateMethods.setTitle,

		/**
		 * 隐藏app分享按钮
		 */
		hideShare: privateMethods.hideShare,

		/**
		 * 打开登录页
		 */
		openLogin: privateMethods.openLogin,

		/**
		 * 获取浏览器所属系统
		 */
		getBrowerType: privateMethods.getBrowerType,

		/**
		 * 获取联系地址
		 */
		getAddress: privateMethods.getAddress,

		/**
		 * 选择材料
		 */
		selectMaterial: privateMethods.selectMaterial,

		/**
		 * 生成材料
		 */
		generateMaterial: privateMethods.generateMaterial,

		/**
		 * 生成材料（自定义材料名）
		 */
		createMaterial: privateMethods.createMaterial,

		/**
		 * 复制
		 */
		copyToClipboard: privateMethods.copyToClipboard,

		/**
		 * 获取APP基础参数
		 */
		getBaseParams: privateMethods.getBaseParams,

		/**
		 * 拨打电话
		 */
		openDial: privateMethods.openDial,

		/**
		 * 预览pdf文件
		 */
		previewPDF: privateMethods.previewPDF,

		/**
		 * 选择代理企业列表
		 */
		selectAgentEnterprise: privateMethods.selectAgentEnterprise,

		/**
		 * app人脸认证
		 */
		appFaceAuth: privateMethods.appFaceAuth,

		/**
		 * app完善企业信息
		 */
		appEnterpriseInfo: privateMethods.appEnterpriseInfo,

		/**
		 * 初始化分享
		 */
		shareInit: privateMethods.shareInit,

		/**
		 * 手动分享
		 */
		shareHandle: privateMethods.shareHandle,

		/**
		 * 从手机相册中选图接口
		 */
		chooseImage: privateMethods.chooseImage,

		/**
		 * 拍摄图片
		 */
		takeImage: privateMethods.takeImage,

		/**
		 * 预览图片
		 */
		previewImage: privateMethods.previewImage,

		/**
		 * 下载图片
		 */
		downloadImage: privateMethods.downloadImage,

		/**
		 * 获取本地图片
		 */
		getLocalImgData: privateMethods.getLocalImgData,

		/**
		 * 开始录音
		 */
		startRecord: privateMethods.startRecord,

		/**
		 * 停止录音
		 */
		stopRecord: privateMethods.stopRecord,

		/**
		 * 开始播放
		 */
		playVoice: privateMethods.playVoice,

		/**
		 * 暂停播放
		 */
		pauseVoice: privateMethods.pauseVoice,

		/**
		 * 停止播放
		 */
		stopVoice: privateMethods.stopVoice,

		/**
		 * 人脸认证
		 */
		faceAuthWithRegister: privateMethods.faceAuthWithRegister,

		/**
		 * 验证人脸认证
		 */
		faceAuthWithAEO: privateMethods.faceAuthWithAEO,

		/**
		 * 市民卡人脸认证
		 */
		openSMKFaceAuth: privateMethods.openSMKFaceAuth,

		/**
		 * 市民卡人脸认证静默
		 */
		openSMKBySilentFaceAuth: privateMethods.openSMKBySilentFaceAuth,

		/**
		 * 绑定银行卡
		 */
		openXMSMKBindBankCard: privateMethods.openXMSMKBindBankCard,
		
		/**
		 * 打开银行卡信息列表
		 */
		openXMSMKGoCardList: privateMethods.openXMSMKGoCardList,
		
		/**
		 * 一手签（预览）
		 */
		openEhandsign: privateMethods.openEhandsign,
		
		/**
		 * 一手签（e手签无UI签名）
		 */
		openEhandsign2: privateMethods.openEhandsign2,
		
		/**
		 * 银行卡认证
		 */
		bankCardValidate: privateMethods.bankCardValidate,

		/**
		 * ixm支付
		 */
		openPay: privateMethods.openPay,

		/**
		 * ixm选择银行卡
		 */
		openSelectCard: privateMethods.openSelectCard,

		/**
		 * 相机横屏能力
		 */
		takeIDCardImage: privateMethods.takeIDCardImage,
		
		/**
		 * 导航
		 */
		navigation : privateMethods.navigation,
		
		/**
		 * 打开客服
		 */
		openCustomerService : privateMethods.openCustomerService,
		/**
		 * 下载文件
		 */
		downloadFile : privateMethods.downloadFile,
		/**
		 * 外籍认证
		 */
		crjCtidldentityVerification:privateMethods.crjCtidldentityVerification
	}

})